##Tinymovr Studio Python

This is the Python client library and application that allows easy interfacing with the Tinymovr motor control board.

###Installing using pip

This is the most straightforward method to install Tinymovr studio and have access to hardware.

    pip install tinymovr

###Installing using git clone

First clone the Tinymovr repo to a local directory:

    git clone https://github.com/yconst/Tinymovr

Then cd to the cloned repo directory and install in developer mode:

    cd Tinymovr/studio/Python
    pip install -e .

###Launching the command line app

    tinymovr

###More information

For documentation:

https://tinymovr.readthedocs.io

For more information on Tinymovr:

https://hackaday.io/project/168650-tinymovr-motor-controller
